spacepy.omni.get_omni — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- omni - module to read and process NASA OMNIWEB data »

# spacepy.omni.get_omni

`spacepy.omni.` `get_omni`(ticks, dbase='QDhourly', **kwargs)

  Returns Qin-Denton OMNI values, interpolated to any time-base from a default hourly resolution

  The update function in toolbox retrieves all available hourly Qin-Denton data, and this function accesses that and interpolates to the given times, returning the OMNI values as a SpaceData (dict-like) with Kp, Dst, dens, velo, Pdyn, ByIMF, BzIMF, G1, G2, G3, etc. (see also http://www.dartmouth.edu/~rdenton/magpar/index.html and http://www.agu.org/pubs/crossref/2007/2006SW000296.shtml )

  Parameters: | ticks : Ticktock class or array-like of datetimes time values for desired output dbase : str (optional) Select data source, options are ‘QDhourly’, ‘OMNI2’, ‘Mergedhourly’ Note - Custom data sources can be specified in the spacepy config file as described in the module documentation.
  Returns: | out : spacepy.datamodel.SpaceData containing all Qin-Denton values at times given by ticks

  Notes

  Note about Qbits: If the status variable is 2, the quantity you are using is fairly well determined. If it is 1, the value has some connection to measured values, but is not directly measured. These values are still better than just using an average value, but not as good as those with the status variable equal to 2. If the status variable is 0, the quantity is based on average quantities, and the values listed are no better than an average value. The lower the status variable, the less confident you should be in the value.

  Examples

      >>> import spacepy.time as spt
      >>> import spacepy.omni as om
      >>> ticks = spt.Ticktock(['2002-02-02T12:00:00', '2002-02-02T12:10:00'], 'ISO')
      >>> d = om.get_omni(ticks)
      >>> d.tree(levels=1)
      +
      |____ByIMF
      |____Bz1
      |____Bz2
      |____Bz3
      |____Bz4
      |____Bz5
      |____Bz6
      |____BzIMF
      |____DOY
      |____Dst
      |____G1
      |____G2
      |____G3
      |____Hr
      |____Kp
      |____Pdyn
      |____Qbits
      |____RDT
      |____UTC
      |____W1
      |____W2
      |____W3
      |____W4
      |____W5
      |____W6
      |____Year
      |____akp3
      |____dens
      |____ticks
      |____velo

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- omni - module to read and process NASA OMNIWEB data »